/* vi:set ts=8 sts=0 sw=8:
 * $Id: msgbar.h,v 1.7 1999/01/06 20:55:58 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __MSGBAR_H__
#define __MSGBAR_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#include <stdarg.h>
#include <gtk/gtk.h>
#include "win.h"

extern int	msgbar_clear(gpointer data);
extern void	msgbar_init(win_t *w, GtkWidget *parent);
extern void	msgbar_printf(win_t *w, const char *fmt, ...);
extern void	msgbar_redraw(void *);
extern void	msgbar_toggle(GtkWidget *wgt, gpointer cbdata);
extern void	msgbar_timeout_add(win_t *w);


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif	/* __MSGBAR_H__ */
